pub fn send_request(payload: HostRequest) -> ResponseFuture ⓘExpand description
Send a request to the host and return a future that resolves when the host
calls back via oo_on_message.
pub fn send_request(payload: HostRequest) -> ResponseFuture ⓘSend a request to the host and return a future that resolves when the host
calls back via oo_on_message.