send_request

Function send_request 

pub fn send_request(payload: HostRequest) -> ResponseFuture 
Send a request to the host and return a future that resolves when the host calls back via oo_on_message.